TIMESTAMP_FORMAT = '%Y-%m-%d %H:%M:%S'
PATCH_FILENAME_TEMPLATE = 'deploy-patch-%(name)s.tar.bz2'
PATCH_INFO_FILENAME_TEMPLATE = '.deploy_patch_info.%(name)s'

DEFAULT_MANIFEST_FILENAME = '.manifest.csv'
NAME_RX = r"^[a-zA-Z0-9_]+$"
